@@ -22,14 +22,14 @@
 #  
 #  
 from __future__ import unicode_literals
-from django.utils.encoding import smart_text
-from django.utils import six
+from django.utils.encoding import force_text
 from django.conf import settings
 from django.http import HttpResponse
 from django.utils.functional import Promise
 from django.utils.translation import ugettext_lazy as _
 from django.utils.timezone import is_aware
 from django.utils.formats import number_format
+from django.utils.cache import add_never_cache_headers
 
 from quickapi.conf import (QUICKAPI_INDENT, QUICKAPI_DECIMAL_LOCALE,
     QUICKAPI_ENSURE_ASCII)
@@ -127,9 +127,9 @@ class JSONEncoder(jsonlib.JSONEncoder):
             if QUICKAPI_DECIMAL_LOCALE:
                 return number_format(o, use_l10n=True, force_grouping=True)
             else:
-                return str(o)
-        elif isinstance(o, Promise):
-            return six.text_type(o)
+                return force_text(o)
+        elif isinstance(o, (Promise, Exception)):
+            return force_text(o)
         else:
             return super(JSONEncoder, self).default(o)
 
@@ -151,6 +151,7 @@ def get_json_response(ctx=None):
     result = tojson(ctx, indent=QUICKAPI_INDENT)
     content_type = "%s; charset=%s" % ("application/json", settings.DEFAULT_CHARSET)
     response = HttpResponse(content_type=content_type)
+    add_never_cache_headers(response)
     if len(result)>512:
         response['Content-encoding'] = 'deflate'
         result = zlib.compress(result)
